@@ -601,7 +601,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                     cartaporte_ubicacion_origen.setAttribute('FechaHoraSalida', ubicacion_data.get('FechaHoraSalida'))
                     cartaporte_ubicacion.appendChild(cartaporte_ubicacion_origen)
                 elif ubicacion_data.get('type') == 'destino':
-                    cartaporte_ubicacion.setAttribute('DistanciaRecorrida', ubicacion_data.get('DistanciaRecorrida'))
+                    cartaporte_ubicacion.setAttribute('DistanciaRecorrida', str(ubicacion_data.get('DistanciaRecorrida')))
                     cartaporte_ubicacion_destino = self.dom.createElement('cartaporte:Destino')
                     cartaporte_ubicacion_destino.setAttribute('RFCDestinatario', ubicacion_data.get('RFCDestinatario'))
                     cartaporte_ubicacion_destino.setAttribute('NombreDestinatario', ubicacion_data.get('NombreDestinatario'))
@@ -611,10 +611,13 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
 
                 cartaporte_ubicacion_domicilio = self.dom.createElement('cartaporte:Domicilio')
                 cartaporte_ubicacion_domicilio.setAttribute('Calle', ubicacion_data.get('Calle'))
-                cartaporte_ubicacion_domicilio.setAttribute('NumeroExterior', ubicacion_data.get('NumeroExterior'))
-                cartaporte_ubicacion_domicilio.setAttribute('Colonia', ubicacion_data.get('Colonia'))
+                if ubicacion_data.get('NumeroExterior') != '':
+                    cartaporte_ubicacion_domicilio.setAttribute('NumeroExterior', ubicacion_data.get('NumeroExterior'))
+                if ubicacion_data.get('Colonia') != '':
+                    cartaporte_ubicacion_domicilio.setAttribute('Colonia', ubicacion_data.get('Colonia'))
                 cartaporte_ubicacion_domicilio.setAttribute('Localidad', ubicacion_data.get('Localidad'))
-                cartaporte_ubicacion_domicilio.setAttribute('Referencia', ubicacion_data.get('Referencia'))
+                if ubicacion_data.get('Referencia') != '':
+                    cartaporte_ubicacion_domicilio.setAttribute('Referencia', ubicacion_data.get('Referencia'))
                 cartaporte_ubicacion_domicilio.setAttribute('Municipio', ubicacion_data.get('Municipio'))
                 cartaporte_ubicacion_domicilio.setAttribute('Estado', ubicacion_data.get('Estado'))
                 cartaporte_ubicacion_domicilio.setAttribute('Pais', ubicacion_data.get('Pais'))
@@ -677,17 +680,21 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 cartaporte_operador.setAttribute('NumLicencia', operador_data.get('NumLicencia'))
                 cartaporte_operador.setAttribute('NombreOperador', operador_data.get('NombreOperador'))
 
-                cartaporte_operador_domicilio = self.dom.createElement('cartaporte:Domicilio')
-                cartaporte_operador_domicilio.setAttribute('Calle', operador_data.get('Calle'))
-                cartaporte_operador_domicilio.setAttribute('NumeroExterior', operador_data.get('NumeroExterior'))
-                cartaporte_operador_domicilio.setAttribute('Colonia', operador_data.get('Colonia'))
-                cartaporte_operador_domicilio.setAttribute('Localidad', operador_data.get('Localidad'))
-                cartaporte_operador_domicilio.setAttribute('Referencia', operador_data.get('Referencia'))
-                cartaporte_operador_domicilio.setAttribute('Municipio', operador_data.get('Municipio'))
-                cartaporte_operador_domicilio.setAttribute('Estado', operador_data.get('Estado'))
-                cartaporte_operador_domicilio.setAttribute('Pais', operador_data.get('Pais'))
-                cartaporte_operador_domicilio.setAttribute('CodigoPostal', operador_data.get('CodigoPostal'))
-                cartaporte_operador.appendChild(cartaporte_operador_domicilio)
+                if operador_data.get('Calle', '') != '':
+                    cartaporte_operador_domicilio = self.dom.createElement('cartaporte:Domicilio')
+                    cartaporte_operador_domicilio.setAttribute('Calle', operador_data.get('Calle'))
+                    if operador_data.get('NumeroExterior', '') != '':
+                        cartaporte_operador_domicilio.setAttribute('NumeroExterior', operador_data.get('NumeroExterior'))
+                    if operador_data.get('Colonia', '') != '':
+                        cartaporte_operador_domicilio.setAttribute('Colonia', operador_data.get('Colonia'))
+                    cartaporte_operador_domicilio.setAttribute('Localidad', operador_data.get('Localidad'))
+                    if operador_data.get('Referencia', '') != '':
+                        cartaporte_operador_domicilio.setAttribute('Referencia', operador_data.get('Referencia'))
+                    cartaporte_operador_domicilio.setAttribute('Municipio', operador_data.get('Municipio'))
+                    cartaporte_operador_domicilio.setAttribute('Estado', operador_data.get('Estado'))
+                    cartaporte_operador_domicilio.setAttribute('Pais', operador_data.get('Pais'))
+                    cartaporte_operador_domicilio.setAttribute('CodigoPostal', operador_data.get('CodigoPostal'))
+                    cartaporte_operador.appendChild(cartaporte_operador_domicilio)
 
                 cartaporte_operadores.appendChild(cartaporte_operador)
             cartaporte_figura_transporte.appendChild(cartaporte_operadores)
